import pathlib
from jinja2 import Environment, PackageLoader, select_autoescape

from .config import get_settings

env = Environment(
    loader=PackageLoader("roco"),
    autoescape=select_autoescape()
)


def get_template():
    cur_dir = pathlib.Path(__file__).parent.resolve()
    template_path = cur_dir / "templates"

    return env.get_template(
        name="runtime-config.js.jinja2",
        parent=str(template_path)
    )


def generate_runtime_config() -> str:
    template = get_template()
    settings = get_settings()

    return template.render(settings)



import sys
import click

from roco.main import generate_runtime_config
from roco.config import get_settings


@click.command()
@click.option(
    '-s',
    '--settings',
    is_flag=True,
    default=False,
    show_default=True,
    help="echo current settings"
)
def run(settings: bool):
    if settings:
        se = get_settings()
        click.echo(f"prefix = {se.Config.env_prefix}")
        click.echo(se.dict())
        sys.exit(0)

    output = generate_runtime_config()
    click.echo(output)


if __name__ == "__main__":
    run()



from pydantic import BaseSettings, root_validator


class Settings(BaseSettings):

    google_client_id: str | None = None
    google_authorize_url: str | None = None
    google_redirect_uri: str | None = None
    google_scope: str = 'openid email'

    github_client_id: str | None = None
    github_authorize_url: str | None = None
    github_redirect_uri: str | None = None
    github_scope: str = 'openid email'

    @root_validator
    def check_google_params(cls, values):
        three_values = [
            values.get('google_client_id'),
            values.get('google_authorize_url'),
            values.get('google_redirect_uri')
        ]
        count = len([v for v in three_values if v])

        if count not in (0, 3):
            raise ValueError(
                'google_client_id, google_authorize_url and google_redirect_uri'
                ' should be either all absent or all present'
            )

        return values

    @root_validator
    def check_github_params(cls, values):
        three_values = [
            values.get('github_client_id'),
            values.get('github_authorize_url'),
            values.get('github_redirect_uri')
        ]
        count = len([v for v in three_values if v])

        if count not in (0, 3):
            raise ValueError(
                'github_client_id, github_authorize_url and github_redirect_uri'
                ' should be either all absent or all present'
            )

        return values

    class Config:
        env_prefix = 'PAPERMERGE__AUTH__'


def get_settings():
    return Settings()
